.g-homepage-container{margin-bottom:10px}.g-homepage-logo-container{border:1px solid #ccc;border-radius:5px;min-height:200px}.g-homepage-logo-container .g-homepage-logo-upload-container{width:350px;padding:0 10px 10px;font-size:.9em;display:inline-block}.g-homepage-logo-container .g-homepage-logo-preview-container{vertical-align:top;border-right:1px solid #ccc;height:200px;margin-right:20px;display:inline-block}.g-homepage-logo-container .g-homepage-logo-preview-container .g-homepage-logo-preview{width:100px;height:100px;margin:30px 30px 20px;position:relative}.g-homepage-logo-container .g-homepage-logo-preview-container .g-homepage-logo-preview img{max-width:100px;max-height:100px;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.g-homepage-logo-container .g-homepage-logo-preview-container #g-homepage-logo-reset{vertical-align:bottom;width:90px;margin-left:30px;display:block}
/*$vite$:1*/